awsmate
=======

.. toctree::
   :maxdepth: 3
   :caption: Overview

   readme
   changelog

.. toctree::
   :maxdepth: 4
   :caption: Modules

   apigateway
   lambdafunction
   s3
   logger

.. toctree::
   :maxdepth: 2
   :caption: Appendix

   genindex
   release_process
   todo

.. sidebar-links::
   :github:
   :pypi: awsmate
